Learn R Programming

xmeta (version 1.1-4)

summary.galaxy: Summarize the objects galaxy

Description

Summary a model of class galaxy fitted by galaxy.

Usage

# S3 method for galaxy
summary(object,...)

Arguments

object

an object inheriting from class galaxy.

...

additional arguments; currently none is used.

Value

A list with the following components: adjusted parameter estimates, variances of estimated parameters

References

Chen, Y., Hong, C., Chu, H., (2015). Galaxy plot and a multivariate method for correcting publication bias in multivariate meta-analysis (in preparation).

See Also

galaxy

Examples

Run this code
# NOT RUN {
data(prostate)
fit.galaxy=galaxy(data=prostate, type = "continuous",
 method="galaxy.cl", k=2, L=1, estimator="R0", maxiter=150)
summary(fit.galaxy)
# }

Run the code above in your browser using DataLab