Learn R Programming

xmeta (version 1.1-4)

summary.mpbt: Summarize the objects mpbt

Description

Summary a model of class mpbt fitted by mpbt.

Usage

# S3 method for mpbt
summary(object,...)

Arguments

object

an object inheriting from class mpbt.

...

additional arguments; currently none is used.

Value

A list with the following components: test statistics (mpbt) and p-value.

References

Hong, C., Chu, H. and Chen Y. (2015). A score test for detecting publication bias in multivariate random-effects meta-analysis (in preparation).

See Also

mpbt

Examples

Run this code
# NOT RUN {
data(prostate)
fit.mpbt=mpbt(data=prostate, method = "nn.cl", type = "continuous", k=2)
summary(fit.mpbt)
# }

Run the code above in your browser using DataLab