powered by
mpbt
Summary a model of class mpbt fitted by mpbt.
# S3 method for mpbt summary(object,...)
an object inheriting from class mpbt.
additional arguments; currently none is used.
A list with the following components: test statistics (mpbt) and p-value.
Hong, C., Chu, H. and Chen Y. (2015). A score test for detecting publication bias in multivariate random-effects meta-analysis (in preparation).
# NOT RUN { data(prostate) fit.mpbt=mpbt(data=prostate, method = "nn.cl", type = "continuous", k=2) summary(fit.mpbt) # }
Run the code above in your browser using DataLab